﻿using Rhino;
using Rhino.Collections;
using Rhino.Commands;

namespace TestKillwater
{
  [System.Runtime.InteropServices.Guid("1917fa88-3716-461d-9d08-c1eb2126dcc9")]
  public class TestKillwaterCommand : Command
  {
    private const string INTEGER_VALUE = "INT";
    private const string DOUBLE_VALUE = "DBL";
    
    private int m_integer_value = 1;
    private double m_double_value = 2.13;

    public TestKillwaterCommand()
    {
      Instance = this;
    }

    /// <summary>
    /// Gets the one and only instance of the TestKillwaterCommand object.
    /// </summary>
    public static TestKillwaterCommand Instance
    {
      get;
      private set;
    }

    /// <summary>
    /// Returns command name as it appears on the Rhino command line.
    /// </summary>
    public override string EnglishName
    {
      get { return "TestKillwater"; }
    }

    /// <summary>
    /// Commands.RunCommand override
    /// </summary>
    protected override Result RunCommand(RhinoDoc doc, RunMode mode)
    {
      GetValues(TestKillwaterPlugIn.GlobalDatabase);
      GetValues(TestKillwaterPlugIn.LocalDatabase);

      SetValues(TestKillwaterPlugIn.GlobalDatabase);
      SetValues(TestKillwaterPlugIn.LocalDatabase);

      return Result.Success;
    }

    private void GetValues(ArchivableDictionary dictionary)
    {
      if (null == dictionary)
        return;

      RhinoApp.WriteLine(dictionary.Name);

      int integer_value;
      if (dictionary.TryGetInteger(INTEGER_VALUE, out integer_value))
      {
        m_integer_value = integer_value;
        RhinoApp.WriteLine("  Integer = {0}", m_integer_value);
      }
      else
        RhinoApp.WriteLine("  Integer = <none>");

      double double_value;
      if (dictionary.TryGetDouble(DOUBLE_VALUE, out double_value))
      {
        m_double_value = double_value;
        RhinoApp.WriteLine("  Double = {0}", m_double_value);
      }
      else
        RhinoApp.WriteLine("  Double = <none>");
    }

    private void SetValues(ArchivableDictionary dictionary)
    {
      if (null == dictionary)
        return;

      m_integer_value++;
      m_double_value *= 1.57;

      dictionary.Set(INTEGER_VALUE, m_integer_value);
      dictionary.Set(DOUBLE_VALUE, m_double_value);
    }

  }
}
